==> haskell-filelock-0.1.1.2-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-filelock.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: filelock
version: 0.1.1.2
id: filelock-0.1.1.2-9HxtlrNhwXq8yLCvIrzm2F
key: filelock-0.1.1.2-9HxtlrNhwXq8yLCvIrzm2F
license: PublicDomain
maintainer: tak@anoak.io
homepage: http://github.com/takano-akio/filelock
synopsis: Portable interface to file locking (flock / LockFileEx)
description:
    This package provides an interface to Windows and Unix
    file locking functionalities.
category: System
author: Takano Akio
exposed: True
indefinite: False
exposed-modules:
    System.FileLock
hidden-modules: System.FileLock.Internal.Flock
                System.FileLock.Internal.LockFileEx
abi: 12f137cf458094d1cf96f71fa3917414
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/filelock-0.1.1.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/filelock-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/filelock-0.1.1.2
hs-libraries: HSfilelock-0.1.1.2-9HxtlrNhwXq8yLCvIrzm2F
depends:
    base-4.10.1.0 unix-2.7.2.2
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             unix-2.7.2.2=1e3caa57de79efd01f1c7566785dcafa
haddock-interfaces: /usr/share/doc/haskell-filelock/html/filelock.haddock
haddock-html: /usr/share/doc/haskell-filelock/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-filelock-0.1.1.2-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-filelock.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: filelock
version: 0.1.1.2
id: filelock-0.1.1.2-BfxQr4k9W7HCNDMTD4DiWO
key: filelock-0.1.1.2-BfxQr4k9W7HCNDMTD4DiWO
license: LicenseRef-PublicDomain
maintainer: tak@anoak.io
author: Takano Akio
homepage: http://github.com/takano-akio/filelock
synopsis: Portable interface to file locking (flock / LockFileEx)
description:
    This package provides an interface to Windows and Unix
    file locking functionalities.
category: System
abi: bba5394823f759cbde4047fc4ebc4e8c
exposed: True
exposed-modules:
    System.FileLock
hidden-modules: System.FileLock.Internal.Flock
                System.FileLock.Internal.LockFileEx
import-dirs: /usr/lib/ghc-8.4.2/site-local/filelock-0.1.1.2
library-dirs: /usr/lib/ghc-8.4.2/site-local/filelock-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/filelock-0.1.1.2
hs-libraries: HSfilelock-0.1.1.2-BfxQr4k9W7HCNDMTD4DiWO
depends:
    base-4.11.1.0 unix-2.7.2.2
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             unix-2.7.2.2=52cd75b8c492339f1bc16a6e08d9b9d7
haddock-interfaces: /usr/share/doc/haskell-filelock/html/filelock.haddock
haddock-html: /usr/share/doc/haskell-filelock/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
